@@ -3,10 +3,12 @@
 #
 
 from pinecone.utils.tracing import init_tracer, init_profiler
+from pinecone.utils import exceptions, get_hostname
 init_tracer()
 init_profiler()
 
 import argparse
+from loguru import logger
 from pinecone.network.zmq_service import ZMQService
 
 if __name__ == '__main__':
@@ -16,4 +18,7 @@ if __name__ == '__main__':
     ZMQService.add_args(parser)
 
     args, unk = parser.parse_known_args()
-    ZMQService.start_with_args(args)
+
+    while True:
+        ZMQService.start_with_args(args)
+        logger.success(f"Exited {get_hostname()}")
