@@ -18,10 +18,12 @@ class NamespacedEngine(Engine):
 
     SUPPORTED_ENGINES = {'approximated': 'pinecone_engine.functions.engine.approximated.ApproximatedEngine',
                          'exact': 'pinecone_engine.functions.engine.exact.ExactEngine',
-                         'exactly': 'pinecone_engine.functions.engine.exact.ExactlyEngine'}
+                         'exactly': 'pinecone_engine.functions.engine.exact.ExactlyEngine',
+                         'hnsw': 'pinecone_engine.functions.engine.hnsw.HNSWEngine'}
     SUPPORTED_ENGINE_IMAGES = {'approximated': 'pinecone/engine/approximated',
                                'exact': 'pinecone/engine/exact',
-                               'exactly': 'pinecone/engine/exactly'}
+                               'exactly': 'pinecone/engine/exactly',
+                               'hnsw': 'pinecone/engine/hnsw'}
 
     @property
     def image(self):
@@ -44,7 +46,6 @@ class NamespacedEngine(Engine):
         """
         super().__init__(*args, **config)
         self.config['engine_type'] = engine_type
-        self.config['engine_cpus'] = math.ceil(self.cpu_request / 1000.0)
         self.engine_class = None
         self.engines = {}
 
