@@ -196,11 +196,7 @@ class IndexGraph(Graph):
             node_type=node_type,
             **engine_args
         )
-        self.aggregator = (
-            None
-            if shards == 1
-            else self._default_aggregator(num_shards=shards, name="aggregator", replicas=gateway_replicas)
-        )
+        self.aggregator = self._default_aggregator(num_shards=shards, name="aggregator", replicas=gateway_replicas)
         self._update_graph()
 
     @sentry
