@@ -27,13 +27,11 @@ def start(servlet_spec: ServletSpec, volume_request=None, persistent_dir=None, n
         asyncio.set_event_loop(loop)
 
     if volume_request:
-        servlet = WALServlet(servlet_spec, num_replicas, persistent_dir, volume_request=volume_request)
+        servlet = WALServlet(servlet_spec, persistent_dir, volume_request=volume_request)
         servlet.start_polling()
         logger.info(f"Before reload: {servlet_spec.get_stats()}")
-        servlet.write_offset(servlet.replica, 0)  # replay all the messages
         loop.run_until_complete(servlet.run_sync(servlet.load_sync, sync_msg_handler))
         logger.info(f"After reload: {servlet_spec.get_stats()}")
-        loop.create_task(servlet.consume_msgs())
     else:
         servlet = ZMQServlet(servlet_spec)
         servlet.start_polling()
@@ -62,15 +60,14 @@ def run_in_servlet(servlet_spec: ServletSpec, function: Callable[..., Awaitable]
     return result
 
 
-def run_in_wal_servlet(servlet_spec: ServletSpec, num_replicas: int, persistent_dir: str,
-                       function: Callable[..., Awaitable], *args):
+def run_in_wal_servlet(servlet_spec: ServletSpec, persistent_dir: str, function: Callable[..., Awaitable], *args):
     try:
         loop = asyncio.get_event_loop()
     except RuntimeError:
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
 
-    servlet = WALServlet(servlet_spec, num_replicas, persistent_dir)
+    servlet = WALServlet(servlet_spec, persistent_dir)
     result = asyncio.run(function(servlet, *args))
     servlet.cleanup()
     loop.stop()
@@ -93,7 +90,9 @@ async def recv_logs(servlet: WALServlet, num: int):
     msgs = []
     while len(msgs) < num:
         try:
-            msgs.append(await asyncio.wait_for(servlet.recv_log_msg(), RECV_TIMEOUT))
+            msg = await asyncio.wait_for(servlet.recv_log_msg(), RECV_TIMEOUT)
+            await servlet.handle_log_msg(msg)
+            msgs.append(msg)
         except asyncio.TimeoutError:
             continue
     return msgs
