@@ -2,7 +2,7 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
-from typing import List, NamedTuple
+from typing import List, NamedTuple, Tuple
 import time
 
 from loguru import logger
@@ -11,11 +11,10 @@ from .api_controller import ControllerAPI
 from .constants import Config
 from .graph import Graph
 from pinecone.utils.sentry import sentry_decorator as sentry
+from pinecone.utils.progressbar import ProgressBar
 
 __all__ = ["describe", "deploy", "stop", "ls", "ServiceMeta"]
 
-DEFAULT_TIMEOUT = 60  # seconds
-
 
 class ServiceMeta(NamedTuple):
     """Metadata of a service."""
@@ -44,16 +43,16 @@ def describe(service_name: str) -> ServiceMeta:
 
 
 @sentry
-def deploy(service_name: str, graph: Graph, **kwargs):
+def deploy(service_name: str, graph: Graph, wait: bool = True, **kwargs) -> Tuple[dict, ProgressBar]:
     """Create a new Pinecone service from the graph.
 
     :param service_name: name of the service
     :type service_name: str
     :param graph: the graphical representation fo the service
     :type graph: :class:`pinecone.graph.Graph`
+    :param wait: wait for the service to deploy. Defaults to ``True``
+    :type wait: bool
     """
-    timeout = kwargs.get("timeout") or DEFAULT_TIMEOUT
-
     graph.validate()
 
     # copy graph
@@ -63,48 +62,51 @@ def deploy(service_name: str, graph: Graph, **kwargs):
     api = _get_controller_api()
 
     if service_name in api.list_services():
-        raise RuntimeError("Service {} already exists.".format(service_name))
+        raise RuntimeError(
+            "A service with the name '{}' already exists. Please deploy your service with a different name.".format(
+                service_name
+            )
+        )
     else:
         response = api.deploy(graph_.to_json())
 
     # Wait for service to deploy
-    if timeout > 0:
-        start_time = time.perf_counter()
-        while True:
-            if time.perf_counter() - start_time > timeout:
-                raise RuntimeError("Time out when waiting for the service to deploy.")
-            status = api.get_status(service_name)
-            logger.info("waiting on deployment of: {}".format(status.get("waiting")))
-            if status.get("ready"):
-                break
-            time.sleep(5)
+    status = api.get_status(service_name)
+    total_deployments = len(status.get("waiting") or []) + len(status.get("crashed") or [])
 
-    return response
+    def get_remaining():
+        """Get the number of pods that still need to be deployed."""
+        status = api.get_status(service_name)
+        logger.info("Deployment status: waiting={}, crashed={}".format(status.get("waiting"), status.get("crashed")))
+        remaining_deployments = len(status.get("waiting") or []) + len(status.get("crashed") or [])
+        return remaining_deployments
+
+    pbar = ProgressBar(total=total_deployments, get_remaining_fn=get_remaining)
+    if wait:
+        pbar.watch()
+    return response, pbar
 
 
 @sentry
-def stop(service_name: str, **kwargs):
+def stop(service_name: str, wait: bool = True, **kwargs) -> Tuple[dict, ProgressBar]:
     """Stops a service.
 
     :param service_name: name of the service
     :type service_name: str
+    :param wait: wait for the service to deploy. Defaults to ``True``
+    :type wait: bool
     """
-    timeout = kwargs.get("timeout") or DEFAULT_TIMEOUT
-
     api = _get_controller_api()
     response = api.stop(service_name)
 
     # Wait for service to stop
-    if timeout > 0:
-        start_time = time.perf_counter()
-        while True:
-            if time.perf_counter() - start_time > timeout:
-                raise RuntimeError("Time out when waiting for the service to stop.")
-            if service_name not in api.list_services():
-                break
-            time.sleep(5)
+    def get_remaining():
+        return 1 * (service_name in api.list_services())
 
-    return response
+    pbar = ProgressBar(total=1, get_remaining_fn=get_remaining)
+    if wait:
+        pbar.watch()
+    return response, pbar
 
 
 @sentry
